@@ -40,15 +40,16 @@ help() {
 	help_no_mtree
 	help_tmpdir
 	help_skipfreespacecheck
+	help_collection_path
+	help_show_game_script
 	help_configfile
 	help_listpackages
 	help_listrequirements
 	help_listavailablescripts
 	help_listsupportedgames
 
-	# do not print a list of supported archives if called throught the "play.it" wrapper script
+	# Do not print a list of supported archives if called throught the "play.it" wrapper script
 	if [ "$script_name" = 'play.it' ]; then
-		help_show_game_script
 		return 0
 	fi
 
@@ -66,7 +67,7 @@ help() {
 	esac
 	print_message 'info' "$message"
 	# shellcheck disable=SC2046
-	information_archives_list $(archives_return_list)
+	information_archives_list $(archives_list)
 
 	return 0
 }
@@ -264,6 +265,24 @@ help_debug() {
 	print_message 'info' "$message"
 }
 
+# Display the --collection-path option usage
+# USAGE: help_collection_path
+help_collection_path() {
+	local messages_language message
+	messages_language=$(messages_language)
+	case "$messages_language" in
+		('fr')
+			message='\tLimiter la recherche de scripts de prise en charge de jeux au chemin donné.\n\n'
+			;;
+		('en'|*)
+			message='\tLimit the search for game scripts to a given path.\n\n'
+			;;
+	esac
+	print_message 'info' '--%s\n' \
+		'collection-path'
+	print_message 'info' "$message"
+}
+
 # display --show-game-script option usage
 # USAGE: help_show_game_script
 help_show_game_script() {
